::: textual_timepiece.timeline
    options:
        members:
            - VerticalTimeline
            - VerticalEntry
            - VerticalTimelineNavigation
            - VerticalRuler
            - RuledVerticalTimeline
            - HorizontalTimeline
            - HorizontalEntry
            - HorizontalTimelineNavigation
            - HorizontalRuler
            - RuledHorizontalTimeline 
        inherited_members: true
